@@ -37,11 +37,12 @@ import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.ssl.SSLAlertEvent;
 import org.mozilla.jss.ssl.SSLCipher;
 import org.mozilla.jss.ssl.SSLHandshakeCompletedEvent;
+import org.mozilla.jss.ssl.SSLProtocolVariant;
 import org.mozilla.jss.ssl.SSLServerSocket;
 import org.mozilla.jss.ssl.SSLSocket;
-import org.mozilla.jss.ssl.SSLSocket.SSLProtocolVariant;
-import org.mozilla.jss.ssl.SSLSocket.SSLVersionRange;
 import org.mozilla.jss.ssl.SSLSocketListener;
+import org.mozilla.jss.ssl.SSLVersion;
+import org.mozilla.jss.ssl.SSLVersionRange;
 import org.mozilla.jss.util.IncorrectPasswordException;
 import org.mozilla.jss.util.Password;
 import org.slf4j.Logger;
@@ -562,8 +563,9 @@ public class TomcatJSS implements SSLSocketListener {
      * or "datagram".
      *
      * @param sslVersionRange_s takes on the form of "min:max" where min/max
-     * values can be "ssl3, tls1_0, tls1_1, or tls1_2". ssl2 is not supported for
-     * tomcatjss via this interface. The format is "sslVersionRange=min:max".
+     * values can be "ssl3, tls1_0, tls1_1, tls1_2, tls1_3". ssl2 is not
+     * supported for tomcatjss via this interface. The format is
+     * "sslVersionRange=min:max".
      */
     public void setSSLVersionRangeDefault(
             String type,
@@ -583,42 +585,18 @@ public class TomcatJSS implements SSLSocketListener {
         logger.debug("* min: " + min_s);
         logger.debug("* max: " + max_s);
 
-        int min = getSSLVersionRangeEnum(min_s);
-        int max = getSSLVersionRangeEnum(max_s);
+        SSLVersion minVersion = SSLVersion.findByAlias(min_s);
+        SSLVersion maxVersion = SSLVersion.findByAlias(max_s);
 
-        if (min == -1 || max == -1) {
-            throw new SocketException("SSL version range format error: " + sslVersionRange_s);
-        }
+        SSLVersionRange range = new SSLVersionRange(minVersion, maxVersion);
+        range = SSLSocket.boundSSLVersionRange(SSLProtocolVariant.STREAM, range);
 
-        SSLVersionRange range = new SSLVersionRange(min, max);
+        logger.debug("Actual SSL version range for " + type + " after system policy correction:");
+        logger.debug("* min: " + range.getMinVersion());
+        logger.debug("* max: " + range.getMaxVersion());
         SSLSocket.setSSLVersionRangeDefault(protoVariant, range);
     }
 
-    int getSSLVersionRangeEnum(String range) {
-
-        if (range == null) {
-            return -1;
-        }
-
-        if (range.equals("ssl3")) {
-            return SSLVersionRange.ssl3;
-        }
-
-        if (range.equals("tls1_0")) {
-            return SSLVersionRange.tls1_0;
-        }
-
-        if (range.equals("tls1_1")) {
-            return SSLVersionRange.tls1_1;
-        }
-
-        if (range.equals("tls1_2")) {
-            return SSLVersionRange.tls1_2;
-        }
-
-        return -1;
-    }
-
     public void setSSLCiphers(String attr, String ciphers) throws SocketException, IOException {
 
         if (StringUtils.isEmpty(ciphers)) {
